==> zio-aws-ec2_2.12-7.21.15.7-sources.jar: zio/aws/ec2/model/DescribeInstanceEventNotificationAttributesRequest.scala <==
package zio.aws.ec2.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class DescribeInstanceEventNotificationAttributesRequest(
    dryRun: Optional[Boolean] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.DescribeInstanceEventNotificationAttributesRequest = {
    import DescribeInstanceEventNotificationAttributesRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.DescribeInstanceEventNotificationAttributesRequest
      .builder()
      .optionallyWith(dryRun.map(value => value: java.lang.Boolean))(_.dryRun)
      .build()
  }
  def asReadOnly
      : zio.aws.ec2.model.DescribeInstanceEventNotificationAttributesRequest.ReadOnly =
    zio.aws.ec2.model.DescribeInstanceEventNotificationAttributesRequest
      .wrap(buildAwsValue())
}
object DescribeInstanceEventNotificationAttributesRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.DescribeInstanceEventNotificationAttributesRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.ec2.model.DescribeInstanceEventNotificationAttributesRequest =
      zio.aws.ec2.model.DescribeInstanceEventNotificationAttributesRequest(
        dryRun.map(value => value)
      )
    def dryRun: Optional[Boolean]
    def getDryRun: ZIO[Any, AwsError, Boolean] =
      AwsError.unwrapOptionField("dryRun", dryRun)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.DescribeInstanceEventNotificationAttributesRequest
  ) extends zio.aws.ec2.model.DescribeInstanceEventNotificationAttributesRequest.ReadOnly {
    override val dryRun: Optional[Boolean] = zio.aws.core.internal
      .optionalFromNullable(impl.dryRun())
      .map(value => value: Boolean)
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.DescribeInstanceEventNotificationAttributesRequest
  ): zio.aws.ec2.model.DescribeInstanceEventNotificationAttributesRequest.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-ec2_2.13-5.17.151.2-sources.jar: zio/aws/ec2/model/DescribeInstanceEventNotificationAttributesRequest.scala <==
package zio.aws.ec2.model
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters._
final case class DescribeInstanceEventNotificationAttributesRequest() {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.DescribeInstanceEventNotificationAttributesRequest = {
    import DescribeInstanceEventNotificationAttributesRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.DescribeInstanceEventNotificationAttributesRequest
      .builder()
      .build()
  }
  def asReadOnly
      : zio.aws.ec2.model.DescribeInstanceEventNotificationAttributesRequest.ReadOnly =
    zio.aws.ec2.model.DescribeInstanceEventNotificationAttributesRequest
      .wrap(buildAwsValue())
}
object DescribeInstanceEventNotificationAttributesRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.DescribeInstanceEventNotificationAttributesRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.ec2.model.DescribeInstanceEventNotificationAttributesRequest =
      zio.aws.ec2.model.DescribeInstanceEventNotificationAttributesRequest()
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.DescribeInstanceEventNotificationAttributesRequest
  ) extends zio.aws.ec2.model.DescribeInstanceEventNotificationAttributesRequest.ReadOnly
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.DescribeInstanceEventNotificationAttributesRequest
  ): zio.aws.ec2.model.DescribeInstanceEventNotificationAttributesRequest.ReadOnly =
    new Wrapper(impl)
}
